######################
# Hardcode PLF build
%bcond_with plf
######################

%if %{with plf}
# make EVR of plf build higher than regular to allow update, needed with rpm5 mkrel
%define extrarelsuffix plf
%endif

%bcond_without vkontakte

%define gstapi 0.10
%define oname Clementine

Summary:	A cross-platform music player based on Amarok 1.4
Name:		clementine
Version:	1.2.3
Release:	2%{?extrarelsuffix}
License:	GPLv3+
Group:		Sound
Url:		http://www.clementine-player.org/
Source0:	http://clementine-player.googlecode.com/files/%{oname}-%{version}.tar.gz
Source1:	Clementine.conf
%if %{with vkontakte}
Source2:	clementine-1.2.0-vk-files.tar.bz2
%endif
Patch0:		clementine-1.2.0-libmygpo-qt.patch
# Search albums at metal-archives.com (Encyclopaedia Metallum) from:
# - Now Playing widget (album art context menu) - current album
# - Playlist (selected songs context menu) - unique selected albums
Patch1:		clementine-1.2.2-metalarchives.patch
# Covers should always fit the screen resolution so we scale them if needed
Patch2:		clementine-1.0.0-coversize.patch
# VKontakte (vk.com) support from http://code.google.com/r/shedwardx-clementine-experiments/
# With some ROSA adjustments (use system vreen library etc)
Patch3:		clementine-1.2.2-vkontakte-advanced.patch
Patch4:		clementine-1.2.0-vkontakte-tags.patch
# Localization issues
Patch5:		clementine-1.2.0-l10n-ru-vkontakte.patch
Patch10:	clementine-1.2.0-l10n-ru-desktop.patch
Patch11:	clementine-1.2.0-l10n-ru-search.patch
Patch12:	clementine-1.2.2-gcc47.patch
Patch13:	clementine-udisks-headers.patch

BuildRequires:	cmake
BuildRequires:	qt4-linguist
BuildRequires:	boost-devel
BuildRequires:	liblastfm-devel
BuildRequires:	qt4-devel >= 4.5.0
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(gstreamer-%{gstapi})
BuildRequires:	pkgconfig(gstreamer-cdda-%{gstapi})
BuildRequires:	pkgconfig(gstreamer-plugins-base-%{gstapi})
BuildRequires:	pkgconfig(gstreamer-tag-%{gstapi})
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavutil)
BuildRequires:	pkgconfig(libcdio)
BuildRequires:	pkgconfig(libchromaprint)
BuildRequires:	pkgconfig(libechonest)
BuildRequires:	pkgconfig(libgpod-1.0)
BuildRequires:	pkgconfig(libmtp)
BuildRequires:	pkgconfig(libmygpo-qt)
BuildRequires:	pkgconfig(libplist)
# For Google Drive integration
BuildRequires:	pkgconfig(libsparsehash)
%if %{with plf}
BuildRequires:	pkgconfig(libspotify)
%endif
BuildRequires:	pkgconfig(libusbmuxd)
# Disable for now as indicate-qt seems to be broken and we don't really need it anyway
#BuildRequires:	pkgconfig(indicate-qt)
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	pkgconfig(qca2)
BuildRequires:	pkgconfig(QJson)
BuildRequires:	pkgconfig(taglib) >= 1.6
BuildRequires:	pkgconfig(vreen)
BuildRequires:	pkgconfig(vreenoauth)
Requires:	libprojectm-data
Requires:	qt4-database-plugin-sqlite
Requires:	gstreamer%{gstapi}-flac
Requires:	gstreamer%{gstapi}-plugins-ugly
Suggests:	gstreamer%{gstapi}-decoders-audio
# Needed to be able to mount ipod/iphone/ipad (not tested locally) but it's also pulling gvfs
# which is need at least to mount mtp devices (tested locally)
Suggests:	gvfs-iphone

%description
Clementine is a modern music player and library organiser. Clementine is
a port of Amarok 1.4, with some features rewritten to take advantage of
Qt4.
Features:
    * Search and play your local music library
    * Listen to internet radio from Last.fm, SomaFM and Magnatune
    * Tabbed playlists, import and export M3U, XSPF, PLS and ASX
    * Visualisations from projectM
    * Transcode music into MP3, Ogg Vorbis, Ogg Speex, FLAC or AAC
    * Edit tags on MP3 and OGG files, organize your music
    * Download missing album cover art from Last.fm
    * Remote control using a Wii Remote, MPRIS or the command-line
    * Copy music to your iPod, iPhone, MTP or mass-storage USB player
    * Queue manage

%files
%config %{_sysconfdir}/Clementine/Clementine.conf
%{_bindir}/clementine
%{_bindir}/clementine-tagreader
%{_datadir}/kde4/services/clementine-*.protocol
%{_datadir}/applications/clementine.desktop
%{_iconsdir}/hicolor/64x64/apps/application-x-clementine.png
%{_iconsdir}/hicolor/scalable/apps/application-x-clementine.svg
%if %{with plf}
%{_bindir}/clementine-spotifyblob
%endif

#----------------------------------------------------------------------------

%prep
%setup -q -n %{oname}-%{version}
%patch0 -p1 -b .mygpo~
%patch1 -p1 -b .ma~
%patch2 -p1 -b .coversize~

%if %{with vkontakte}
tar -xf %{SOURCE2}
%patch3 -p1 -b .vkontakte~
%patch4 -p1 -b .vkontakte~
%patch5 -p1 -b .vkontakte~
%endif

%patch10 -p1 -b .l10n~
%patch11 -p1 -b .l10n~

%patch12 -p1 -b .gcc47~
%patch13 -p1 -b .udisks~

%build
%cmake_qt4 \
	-DBUNDLE_PROJECTM_PRESETS=OFF \
	-DBUILD_WERROR=OFF
%make VERBOSE=1

%install
%makeinstall_std -C build

install -m 644 -D %{SOURCE1} %{buildroot}%{_sysconfdir}/Clementine/Clementine.conf

%if %{with plf}
# Ugly hack, not sure why that file appears
rm -rf %{buildroot}/builddir
rm -rf %{buildroot}/home
%endif


%changelog
* Tue Jul 01 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.3-2
+ Revision: 7329efe
- Add patch to fix build with cmake 3.0

* Mon May 26 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.3-1
+ Revision: 51674d3
- Make build verbose

* Mon May 26 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.3-1
+ Revision: d6b7e89
- New version 1.2.3

* Wed May 07 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.2-2
+ Revision: 88d2e64
- Bump release

* Mon Mar 03 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.2-1
+ Revision: b122827
- LOG New version 1.2.2

* Mon Oct 28 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-8
+ Revision: fe880eb
- Add missing patch

* Mon Oct 28 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-8
+ Revision: e001d37
- Update source

* Mon Oct 28 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-8
+ Revision: ace94e2
- LOG Improve Vk.com support (now supports albums/playlists), fix minor localization issues

* Thu Oct 24 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-6
+ Revision: b3efdb7
- LOG Improve VKontakte support

* Tue Oct 22 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-5
+ Revision: 2a1f551
- LOG Update russian translation for .desktop file

* Tue Oct 22 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-5
+ Revision: ffd226e
- LOG Add russian strings to desktop file, don't read tags for vk.com music files (it fixes encoding issues because we already have tags properly set)

* Wed Oct 16 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-4
+ Revision: 36d6857
- LOG Add patch for VKontakte support

* Wed Oct 16 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-3
+ Revision: 23b599a
- Adjust removal of junk from buildroot

* Wed Oct 16 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-3
+ Revision: 1d0f819
- LOG Update BuildRequires

* Wed Oct 16 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.2.0-2
+ Revision: e96cac4
- LOG New version 1.2.0, re-diff MA patch, drop no longer needed patches, update BuildRequires

* Mon Jun 03 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.1.1-4
+ Revision: 2f39d75
- LOG Rebuild for new libechonest

* Tue Jan 29 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.1.1-3
+ Revision: 9b60706
- LOG Rebuild for new qjson

* Wed Dec 12 2012 Denis Silakov <denis.silakov@rosalab.ru> 1.1.1-2plf
+ Revision: 5e584af
- Added spotify support for PLF build, clean .abf.yml

* Wed Nov 21 2012 Alexander Khryukin <alexander@mezon.ru> 1.1.1-1
+ Revision: 60453c2
- version update clementine-1.1.1.tar.gz

* Fri Oct 26 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.1.0-1
+ Revision: b26c3cd
- Don't use _sourcedir in spec

* Fri Oct 26 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.1.0-1
+ Revision: 6a0f636
- LOG Update files list

* Fri Oct 26 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.1.0-1
+ Revision: d1dacea
- LOG Update metal archives patch

* Fri Oct 26 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.1.0-1
+ Revision: c5a4aba
- LOG Add pkgconfig(protobuf) to BuildRequires

* Fri Oct 26 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.1.0-1
+ Revision: a1cc326
- LOG Re-diff metal-archives patch

* Fri Oct 26 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.1.0-1
+ Revision: 7093985
- LOG New version 1.1.0
- Drop no longer needed patches
- Re-diff fix-desktop patch

* Mon Oct 22 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.0.1-4
+ Revision: 89c686a
- LOG Update russian translation from upstream

* Wed Sep 12 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.0.1-3
+ Revision: 03ed397
- LOG Disable libindicate-qt BuildRequires and we don't really want it

* Wed Sep 12 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.0.1-3
+ Revision: 50b7f8e
- LOG Add patches to fix build with new liblastfm and to fix desktop file

* Sun Aug 26 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.0.1-2
+ Revision: 1876d53
- LOG Add patch from upstream to fix build with new imobiledevice libs

* Sun Aug 26 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.0.1-2
+ Revision: 495d4c3
- LOG Add 2 patches from Fedora to fix some crashes, build without -Werror


